==> fi-security-integration-0.0.1-20140512.120059-2-sources.jar: org/fao/fi/security/integration/test/support/services/WebAppServicesTestConfiguration.java <==
/**
 * (c) 2014 FAO / UN (project: reports-store-gateway-web-base)
 */
package org.fao.fi.security.integration.test.support.services;

import org.fao.fi.security.client.javax.filters.EncryptedOutputResponseDecorator;
import org.fao.fi.security.integration.test.support.javax.filters.EncryptedTokenSecuredResourceRequestValidatorTestFilter;
import org.fao.fi.security.integration.test.support.javax.filters.PlainTokenSecuredResourceRequestValidatorTestFilter;
import org.fao.fi.security.server.javax.filters.bandwidth.BandwidthLimitedResourceRequestValidatorFilter;
import org.fao.fi.security.server.javax.filters.origin.IPRestrictedResourceRequestValidatorFilter;
import org.fao.fi.security.server.javax.interceptors.EncryptedResourceWriterInterceptor;
import org.glassfish.jersey.server.ResourceConfig;

/**
 * Place your class / interface description here.
 *
 * History:
 *
 * ------------- --------------- -----------------------
 * Date			 Author			 Comment
 * ------------- --------------- -----------------------
 * 30 Apr 2014   Fiorellato     Creation.
 *
 * @version 1.0
 * @since 30 Apr 2014
 */
public class WebAppServicesTestConfiguration extends ResourceConfig {
	/**
	 * Class constructor
	 */
	public WebAppServicesTestConfiguration() {
		register(BandwidthLimitedResourceRequestValidatorFilter.class);
		register(IPRestrictedResourceRequestValidatorFilter.class);
		register(EncryptedResourceWriterInterceptor.class);
		register(EncryptedOutputResponseDecorator.class);
		register(PlainTokenSecuredResourceRequestValidatorTestFilter.class);
		register(EncryptedTokenSecuredResourceRequestValidatorTestFilter.class);
	}
}

==> fi-security-integration-1.0.0-20140716.140355-11-sources.jar: org/fao/fi/security/integration/test/support/services/WebAppServicesTestConfiguration.java <==
/**
 * (c) 2014 FAO / UN (project: reports-store-gateway-web-base)
 */
package org.fao.fi.security.integration.test.support.services;

import org.fao.fi.security.client.javax.filters.EncryptedResponseDecorator;
import org.fao.fi.security.integration.test.support.javax.filters.EncryptedTokenSecuredResourceRequestValidatorTestFilter;
import org.fao.fi.security.integration.test.support.javax.filters.PlainTokenSecuredResourceRequestValidatorTestFilter;
import org.fao.fi.security.server.javax.filters.bandwidth.BandwidthLimitedResourceRequestValidatorFilter;
import org.fao.fi.security.server.javax.filters.origin.IPRestrictedResourceRequestValidatorFilter;
import org.fao.fi.security.server.javax.interceptors.EncryptedResourceReaderInterceptor;
import org.fao.fi.security.server.javax.interceptors.EncryptedResourceWriterInterceptor;
import org.glassfish.jersey.server.ResourceConfig;

/**
 * Place your class / interface description here.
 *
 * History:
 *
 * ------------- --------------- -----------------------
 * Date			 Author			 Comment
 * ------------- --------------- -----------------------
 * 30 Apr 2014   Fiorellato     Creation.
 *
 * @version 1.0
 * @since 30 Apr 2014
 */
public class WebAppServicesTestConfiguration extends ResourceConfig {
	/**
	 * Class constructor
	 */
	public WebAppServicesTestConfiguration() {
		register(BandwidthLimitedResourceRequestValidatorFilter.class);
		register(IPRestrictedResourceRequestValidatorFilter.class);
		
		register(EncryptedResponseDecorator.class);

		register(EncryptedResourceWriterInterceptor.class);
		register(EncryptedResourceReaderInterceptor.class);
		
		register(PlainTokenSecuredResourceRequestValidatorTestFilter.class);
		register(EncryptedTokenSecuredResourceRequestValidatorTestFilter.class);
	}
}
